/*
 * Copyright (C) 2004 the xine-project
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 *
 * $Id: player.h,v 1.3 2005/01/12 00:26:33 dsalt Exp $
 *
 * xine engine wrapper
 */
#ifndef HAVE_PLAYER_H
#define HAVE_PLAYER_H

void player_init (void);

const char *player_get_cur_title (void);
const char *player_get_cur_mrl (void);

void player_launch (const char *tiele, const char *mrl, int pos, int pos_time);

int player_live_stream (void);

#endif
